@@ -29,6 +29,8 @@
 #include "PTBatcherGUI.h"
 #include "FindPanoDialog.h"
 #include "FailedProjectsDialog.h"
+#include "ChangeUserDefinedDialog.h"
+#include "GenerateSequenceDialog.h"
 #ifdef __WXMSW__
 #include <powrprof.h>
 #ifdef _MSC_VER
@@ -79,8 +81,7 @@ bool BatchDropTarget::OnDropFiles(wxCoord x, wxCoord y, const wxArrayString& fil
 
 enum
 {
-    wxEVT_COMMAND_RELOAD_BATCH,
-    wxEVT_COMMAND_UPDATE_LISTBOX
+    EVT_TIMER_UPDATE_LISTBOX
 };
 
 BEGIN_EVENT_TABLE(BatchFrame, wxFrame)
@@ -99,6 +100,7 @@ BEGIN_EVENT_TABLE(BatchFrame, wxFrame)
     EVT_MENU(XRCID("menu_remove"),BatchFrame::OnButtonRemoveFromList)
     EVT_MENU(XRCID("menu_adddir"),BatchFrame::OnButtonAddDir)
     EVT_MENU(XRCID("menu_searchpano"), BatchFrame::OnButtonSearchPano)
+    EVT_MENU(XRCID("menu_generate_sequence"), BatchFrame::OnButtonGenerateSequence)
     EVT_MENU(XRCID("menu_open"),BatchFrame::OnButtonOpenBatch)
     EVT_MENU(XRCID("menu_save"),BatchFrame::OnButtonSaveBatch)
     EVT_MENU(XRCID("menu_clear"),BatchFrame::OnButtonClear)
@@ -108,6 +110,7 @@ BEGIN_EVENT_TABLE(BatchFrame, wxFrame)
     EVT_BUTTON(XRCID("button_addcommand"),BatchFrame::OnButtonAddCommand)
     EVT_BUTTON(XRCID("button_remove"),BatchFrame::OnButtonRemoveComplete)
     EVT_BUTTON(XRCID("button_prefix"),BatchFrame::OnButtonChangePrefix)
+    EVT_BUTTON(XRCID("button_user_defined"), BatchFrame::OnButtonChangeUserDefinedSequence)
     EVT_BUTTON(XRCID("button_reset"),BatchFrame::OnButtonReset)
     EVT_BUTTON(XRCID("button_resetall"),BatchFrame::OnButtonResetAll)
     EVT_BUTTON(XRCID("button_edit"),BatchFrame::OnButtonOpenWithHugin)
@@ -121,8 +124,7 @@ BEGIN_EVENT_TABLE(BatchFrame, wxFrame)
     EVT_CHECKBOX(XRCID("cb_savelog"), BatchFrame::OnCheckSaveLog)
     EVT_END_PROCESS(-1, BatchFrame::OnProcessTerminate)
     EVT_CLOSE(BatchFrame::OnClose)
-    EVT_MENU(wxEVT_COMMAND_RELOAD_BATCH, BatchFrame::OnReloadBatch)
-    EVT_MENU(wxEVT_COMMAND_UPDATE_LISTBOX, BatchFrame::OnUpdateListBox)
+    EVT_TIMER(EVT_TIMER_UPDATE_LISTBOX, BatchFrame::OnUpdateListBox)
     EVT_COMMAND(wxID_ANY, EVT_BATCH_FAILED, BatchFrame::OnBatchFailed)
     EVT_COMMAND(wxID_ANY, EVT_INFORMATION, BatchFrame::OnBatchInformation)
     EVT_COMMAND(wxID_ANY, EVT_UPDATE_PARENT, BatchFrame::OnRefillListBox)
@@ -134,7 +136,6 @@ BatchFrame::BatchFrame(wxLocale* locale, wxString xrc)
 {
     this->SetLocaleAndXRC(locale,xrc);
     m_cancelled = false;
-    m_closeThread = false;
 
     //load xrc resources
     wxXmlResource::Get()->LoadFrame(this, (wxWindow* )NULL, wxT("batch_frame"));
@@ -158,12 +159,14 @@ BatchFrame::BatchFrame(wxLocale* locale, wxString xrc)
     m_iconNormal = wxIcon(m_xrcPrefix + wxT("data/ptbatcher.ico"), wxBITMAP_TYPE_ICO);
     m_iconRunning = wxIcon(m_xrcPrefix + wxT("data/ptbatcher_running.ico"), wxBITMAP_TYPE_ICO);
     m_iconPaused = wxIcon(m_xrcPrefix + wxT("data/ptbatcher_pause.ico"), wxBITMAP_TYPE_ICO);
+    wxIconBundle myIcons(m_xrcPrefix + wxT("data/ptbatcher.ico"), wxBITMAP_TYPE_ICO);
+    SetIcons(myIcons);
 #else
     m_iconNormal = wxIcon(m_xrcPrefix + wxT("data/ptbatcher.png"), wxBITMAP_TYPE_PNG);
     m_iconRunning = wxIcon(m_xrcPrefix + wxT("data/ptbatcher_running.png"), wxBITMAP_TYPE_PNG);
     m_iconPaused = wxIcon(m_xrcPrefix + wxT("data/ptbatcher_pause.png"), wxBITMAP_TYPE_PNG);
-#endif
     SetIcon(m_iconNormal);
+#endif
 
     m_batch = new Batch(this);
     if(wxGetKeyState(WXK_COMMAND))
@@ -184,16 +187,17 @@ BatchFrame::BatchFrame(wxLocale* locale, wxString xrc)
             wxYES_NO | wxICON_EXCLAMATION, NULL)==wxNO)
         {
             m_batch->LoadTemp();
+        }
+        else
+        {
+            // save empty batch queue
+            m_batch->SaveTemp();
         };
     }
     else
     {
         m_batch->LoadTemp();
     };
-    if(m_batch->GetLastFile().length()==0)
-    {
-        m_batch->SaveTemp();
-    }
     projListBox = XRCCTRL(*this,"project_listbox",ProjectListBox);
     // fill at end list box, check which options are available
     m_endChoice = XRCCTRL(*this, "choice_end", wxChoice);
@@ -219,8 +223,6 @@ BatchFrame::BatchFrame(wxLocale* locale, wxString xrc)
     };
 #endif
 
-    this->wxThreadHelper::CreateThread();
-    this->GetThread()->Run();
     //TO-DO: include a batch or project progress gauge?
     projListBox->Fill(m_batch);
     SetDropTarget(new BatchDropTarget());
@@ -244,34 +246,9 @@ BatchFrame::BatchFrame(wxLocale* locale, wxString xrc)
     // check settings of help window and fix when needed
     FixHelpSettings();
 #endif
-}
-
-void* BatchFrame::Entry()
-{
-    //we constantly poll the working dir for new files and wait a bit on each loop
-    while(!m_closeThread)
-    {
-        //don't access GUI directly in this function (function is running as separate thread)
-        //check, if ptbt file was changed
-        wxFileName aFile(m_batch->GetLastFile());
-        if(!aFile.FileExists())
-        {
-            wxQueueEvent(this, new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, wxEVT_COMMAND_RELOAD_BATCH));
-        }
-        else
-        {
-            wxDateTime create;
-            aFile.GetTimes(NULL,NULL,&create);
-            if(create.IsLaterThan(m_batch->GetLastFileDate()))
-            {
-                wxQueueEvent(this, new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, wxEVT_COMMAND_RELOAD_BATCH));
-            };
-        };
-        //update project list box
-        wxQueueEvent(this, new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, wxEVT_COMMAND_UPDATE_LISTBOX));
-        GetThread()->Sleep(1000);
-    }
-    return 0;
+    m_updateProjectsTimer = new wxTimer(this, EVT_TIMER_UPDATE_LISTBOX);
+    // start timer for check for updates in project files
+    m_updateProjectsTimer->StartOnce(5000);
 }
 
 wxStatusBar* BatchFrame::OnCreateStatusBar(int number, long style, wxWindowID id, const wxString& name)
@@ -291,7 +268,7 @@ bool BatchFrame::IsPaused()
     return m_batch->IsPaused();
 };
 
-void BatchFrame::OnUpdateListBox(wxCommandEvent& event)
+void BatchFrame::OnUpdateListBox(wxTimerEvent& event)
 {
     wxFileName tempFile;
     bool change = false;
@@ -322,6 +299,17 @@ void BatchFrame::OnUpdateListBox(wxCommandEvent& event)
                     };
                     projListBox->ReloadProject(projListBox->GetIndex(m_batch->GetProject(i)->id),m_batch->GetProject(i));
                 }
+                if (!m_batch->GetProject(i)->userDefindSequence.empty())
+                {
+                    // check for existence of user defined sequence
+                    if (!wxFileName::FileExists(m_batch->GetProject(i)->userDefindSequence))
+                    {
+                        change = true;
+                        m_batch->GetProject(i)->skip = true;
+                        m_batch->SetStatus(i, Project::MISSING);
+                        projListBox->SetMissing(projListBox->GetIndex(m_batch->GetProject(i)->id));
+                    };
+                };
             }
             else
             {
@@ -342,16 +330,9 @@ void BatchFrame::OnUpdateListBox(wxCommandEvent& event)
     if(change)
     {
         m_batch->SaveTemp();
-    }
-};
-
-void BatchFrame::OnReloadBatch(wxCommandEvent& event)
-{
-    m_batch->ClearBatch();
-    m_batch->LoadTemp();
-    projListBox->DeleteAllItems();
-    projListBox->Fill(m_batch);
-    SetStatusText(wxT(""));
+    };
+    // start timer again
+    m_updateProjectsTimer->StartOnce(2000);
 };
 
 void BatchFrame::OnUserExit(wxCommandEvent& event)
@@ -394,6 +375,39 @@ void BatchFrame::OnButtonSearchPano(wxCommandEvent& e)
     findpano_dlg.ShowModal();
 };
 
+void BatchFrame::OnButtonGenerateSequence(wxCommandEvent& e)
+{
+    wxString defaultdir = wxConfigBase::Get()->Read(wxT("/BatchFrame/actualPath"), wxT(""));
+    wxFileDialog dlg(0,
+        _("Specify project source file(s)"),
+        defaultdir, wxT(""),
+        _("Project files (*.pto)|*.pto|All files (*)|*"),
+        wxFD_OPEN , wxDefaultPosition);
+    dlg.SetDirectory(defaultdir);
+
+    if (dlg.ShowModal() == wxID_OK)
+    {
+        wxConfig::Get()->Write(wxT("/BatchFrame/actualPath"), wxPathOnly(dlg.GetPath()));
+        GenerateSequenceDialog sequenceDialog(this, m_xrcPrefix, dlg.GetPath());
+        if (sequenceDialog.IsValidPanorama())
+        {
+            if (sequenceDialog.ShowModal())
+            {
+            };
+        }
+        else
+        {
+            wxMessageBox(wxString::Format(_("Could not read file %s as valid Hugin pto file."), dlg.GetPath()),
+#ifdef __WXMSW__
+                wxT("PTBatcherGUI"),
+#else
+                wxEmptyString,
+#endif
+                wxOK | wxICON_EXCLAMATION, NULL);
+        };
+    };
+};
+
 void BatchFrame::OnButtonAddToStitchingQueue(wxCommandEvent& event)
 {
     wxString defaultdir = wxConfigBase::Get()->Read(wxT("/BatchFrame/actualPath"),wxT(""));
@@ -472,9 +486,9 @@ void BatchFrame::AddDirToList(wxString aDir)
     SetStatusText(wxString::Format(_("Added projects from dir %s"), aDir.c_str()));
 };
 
-void BatchFrame::AddToList(wxString aFile,Project::Target target)
+void BatchFrame::AddToList(wxString aFile, Project::Target target, wxString userDefined)
 {
-    m_batch->AddProjectToBatch(aFile,wxT(""),target);
+    m_batch->AddProjectToBatch(aFile, wxEmptyString, userDefined, target);
     wxString s;
     switch(target)
     {
@@ -490,6 +504,15 @@ void BatchFrame::AddToList(wxString aFile,Project::Target target)
     m_batch->SaveTemp();
 }
 
+void BatchFrame::AddArrayToList(const wxArrayString& fileList, Project::Target target)
+{
+    for (size_t i = 0; i < fileList.GetCount(); ++i)
+    {
+        m_batch->AddProjectToBatch(fileList[i], wxEmptyString, wxEmptyString, target);
+        projListBox->AppendProject(m_batch->GetProject(m_batch->GetProjectCount() - 1));
+    };
+    m_batch->SaveTemp();
+}
 
 void BatchFrame::OnButtonCancel(wxCommandEvent& event)
 {
@@ -512,7 +535,7 @@ void BatchFrame::OnButtonChangePrefix(wxCommandEvent& event)
         if (project->target == Project::STITCHING)
         {
             wxFileName prefix(project->prefix);
-            wxFileDialog dlg(0,_("Specify output prefix for project ")+project->path,
+            wxFileDialog dlg(0, wxString::Format(_("Specify output prefix for project %s"), project->path),
                              prefix.GetPath(),
                              prefix.GetFullName(), wxT(""),
                              wxFD_SAVE, wxDefaultPosition);
@@ -586,6 +609,61 @@ void BatchFrame::ChangePrefix(int index,wxString newPrefix)
     projListBox->ChangePrefix(i,newPrefix);
 }
 
+void BatchFrame::ChangeUserDefined(int index, wxString newUserDefined)
+{
+    int i;
+    if (index != -1)
+    {
+        i = index;
+    }
+    else
+    {
+        i = m_batch->GetProjectCount() - 1;
+    }
+    m_batch->ChangeUserDefined(i, newUserDefined);
+    projListBox->ChangeUserDefined(i, newUserDefined);
+}
+
+void BatchFrame::OnButtonChangeUserDefinedSequence(wxCommandEvent& event)
+{
+    HuginBase::UIntSet selectedProjects = projListBox->GetSelectedProjects();
+    if (selectedProjects.empty())
+    {
+        SetStatusText(_("Please select a project"));
+    }
+    else
+    {
+        Project* project = m_batch->GetProject(*selectedProjects.begin());
+        const Project::Target target = project->target;
+        for (auto& i : selectedProjects)
+        {
+            const Project* projectI = m_batch->GetProject(i);
+            if (projectI->id < 0)
+            {
+                wxBell();
+                SetStatusText(_("Changing user defined sequence is not possible for application entries."));
+                return;
+            };
+            if (target != projectI->target)
+            {
+                wxBell();
+                SetStatusText(_("You can change the user defined sequence only for the same type of operation (either stitching or assistant)."));
+                return;
+            }
+        };
+        ChangeUserDefinedSequenceDialog dialog(this, m_xrcPrefix, project->userDefindSequence, target == Project::DETECTING);
+        if (dialog.ShowModal() == wxID_OK)
+        {
+            const wxString newUserDefined = dialog.GetNewSequence();
+            for (auto& i : selectedProjects)
+            {
+                m_batch->ChangeUserDefined(i, newUserDefined);
+                projListBox->ChangeUserDefined(i, newUserDefined);
+            };
+        };
+    };
+}
+
 void BatchFrame::OnButtonClear(wxCommandEvent& event)
 {
     int returnCode = m_batch->ClearBatch();
@@ -652,7 +730,7 @@ void BatchFrame::OnButtonOpenBatch(wxCommandEvent& event)
     wxFileDialog dlg(0,
                      _("Specify batch file to open"),
                      defaultdir, wxT(""),
-                     _("Batch files (*.ptb)|*.ptb;|All files (*)|*"),
+                     _("Batch file (*.ptq)|*.ptq;|All files (*)|*"),
                      wxFD_OPEN, wxDefaultPosition);
     if (dlg.ShowModal() == wxID_OK)
     {
@@ -898,7 +976,7 @@ void BatchFrame::OnButtonSaveBatch(wxCommandEvent& event)
     wxFileDialog dlg(0,
                      _("Specify batch file to save"),
                      defaultdir, wxT(""),
-                     _("Batch file (*.ptb)|*.ptb;|All files (*)|*"),
+                     _("Batch file (*.ptq)|*.ptq;|All files (*)|*"),
                      wxFD_SAVE | wxFD_OVERWRITE_PROMPT, wxDefaultPosition);
     if (dlg.ShowModal() == wxID_OK)
     {
@@ -1172,16 +1250,12 @@ void BatchFrame::OnClose(wxCloseEvent& event)
         };
     }
     config->Flush();
-    m_closeThread = true;
-    if (this->GetThread() && this->GetThread()->IsRunning())
-    {
-        this->GetThread()->Wait();
-    };
     if(m_tray!=NULL)
     {
         delete m_tray;
         m_tray = NULL;
     }
+    delete m_updateProjectsTimer;
     this->Destroy();
 }
 
@@ -1260,7 +1334,11 @@ void BatchFrame::RestoreSize()
     }
     else
     {
-        SetSize(600,400);
+#if wxCHECK_VERSION(3,1,0)
+        SetSize(this->FromDIP(wxSize(600,400)));
+#else
+        SetSize(600, 400);
+#endif
     }
 
     if(max==1)
@@ -1322,7 +1400,7 @@ void BatchFrame::OnProgress(wxCommandEvent& e)
 
 void BatchFrame::UpdateTaskBarProgressBar()
 {
-#if defined __WXMSW__ && wxCHECK_VERSION(3,1,0)
+#if defined __WXMSW__ && wxCHECK_VERSION(3,1,0) && wxUSE_TASKBARBUTTON
     // provide also a feedback in task bar if available
     if (IsShown())
     {
